import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
const jwt = require('jsonwebtoken');
const originalPush = VueRouter.prototype.push;
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch((err) => err);
};
Vue.use(VueRouter);
const market = [
  {
    path: '/market/patentInfo/index',
    meta: { title: '专利超市-专利展示' },
    component: () => import('../views/market/patentInfo/index.vue'),
  },
  {
    path: '/market/transfer/index',
    meta: { title: '专利超市-专利转让' },
    component: () => import('../views/market/transfer/index.vue'),
  },
  {
    path: '/market/demand/index',
    meta: { title: '专利超市-专利需求' },
    component: () => import('../views/market/demand/index.vue'),
  },
  {
    path: '/market/navigation/index',
    meta: { title: '专利超市-专利导航' },
    component: () => import('../views/market/navigation/index.vue'),
  },
];
const service = [
  {
    path: '/service/notice/index',
    meta: { title: '咨询服务-政策资讯' },
    component: () => import('../views/service/notice/index.vue'),
  },
  {
    path: '/service/law/index',
    meta: { title: '咨询服务-法律法规' },
    component: () => import('../views/service/law/index.vue'),
  },
  {
    path: '/service/interflow/index',
    meta: { title: '咨询服务-交流互动' },
    component: () => import('../views/service/interflow/index.vue'),
  },
];
const web = [
  {
    path: '/',
    name: 'index',
    meta: { title: '网站首页' },
    component: () => import('../views/index.vue'),
  },
  ...market,
  ...service,
  {
    path: '/login',
    name: 'login',
    meta: { title: '登录', key: 'login' },
    component: () => import('../views/login.vue'),
  },
  {
    path: '/register',
    name: 'register',
    meta: { title: '账户注册', key: 'register' },
    component: () => import('../views/register.vue'),
  },
];
const routes = [...web];
const router = new VueRouter({
  mode: 'history',
  base: process.env.VUE_APP_ROUTER,
  routes,
});
router.beforeEach((to, from, next) => {
  let openid = to.query.openid;
  sessionStorage.setItem('openid', openid);
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (to.path == '/account/index') {
    if (!token) {
      next(`/login?path=${to.path}`);
    } else {
      let user = jwt.decode(token);
      store.commit('setUser', user, { root: true });
      next();
    }
  } else {
    let user = jwt.decode(token);
    store.commit('setUser', user, { root: true });
    next();
  }
});

export default router;
